prepare_node

Function prepare_node 

pub fn prepare_node(
    node: &InstallNode,
    action: &InstallAction,
    m: Option<&MultiProgress>,
    build_type: Option<&str>,
    verbose: bool,
) -> Result<PreparedNode>
Performs the non-destructive first phase of installation: “Preparation”.

Preparation includes:

  • Downloading pre-built archives from the registry.
  • Verifying checksums and PGP signatures (Root of Trust).
  • Or, building the package from source in a temporary sandbox if requested.

This phase always runs in user-space and does not modify the system state or the package store.