Structs
- Dependency
Graph - A Directed Acyclic Graph (DAG) representing the installation plan.
- Install
Node - Represents a single package node within the resolved dependency graph.
Functions
- build_
graph_ from_ locked_ packages - resolve_
dependency_ graph - Computes the complete dependency graph for a set of input sources.